==> pulumi-azure-native-kotlin-2.30.0.0-sources.jar: com/pulumi/azurenative/batch/kotlin/inputs/AzureBlobFileSystemConfigurationArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.batch.kotlin.inputs

import com.pulumi.azurenative.batch.inputs.AzureBlobFileSystemConfigurationArgs.builder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiNullFieldException
import com.pulumi.kotlin.PulumiTagMarker
import com.pulumi.kotlin.applySuspend
import kotlin.String
import kotlin.Suppress
import kotlin.Unit
import kotlin.jvm.JvmName

/**
 *
 * @property accountKey This property is mutually exclusive with both sasKey and identity; exactly one must be specified.
 * @property accountName
 * @property blobfuseOptions These are 'net use' options in Windows and 'mount' options in Linux.
 * @property containerName
 * @property identityReference This property is mutually exclusive with both accountKey and sasKey; exactly one must be specified.
 * @property relativeMountPath All file systems are mounted relative to the Batch mounts directory, accessible via the AZ_BATCH_NODE_MOUNTS_DIR environment variable.
 * @property sasKey This property is mutually exclusive with both accountKey and identity; exactly one must be specified.
 */
public data class AzureBlobFileSystemConfigurationArgs(
    public val accountKey: Output<String>? = null,
    public val accountName: Output<String>,
    public val blobfuseOptions: Output<String>? = null,
    public val containerName: Output<String>,
    public val identityReference: Output<ComputeNodeIdentityReferenceArgs>? = null,
    public val relativeMountPath: Output<String>,
    public val sasKey: Output<String>? = null,
) : ConvertibleToJava<com.pulumi.azurenative.batch.inputs.AzureBlobFileSystemConfigurationArgs> {
    override fun toJava(): com.pulumi.azurenative.batch.inputs.AzureBlobFileSystemConfigurationArgs =
        com.pulumi.azurenative.batch.inputs.AzureBlobFileSystemConfigurationArgs.builder()
            .accountKey(accountKey?.applyValue({ args0 -> args0 }))
            .accountName(accountName.applyValue({ args0 -> args0 }))
            .blobfuseOptions(blobfuseOptions?.applyValue({ args0 -> args0 }))
            .containerName(containerName.applyValue({ args0 -> args0 }))
            .identityReference(identityReference?.applyValue({ args0 -> args0.let({ args0 -> args0.toJava() }) }))
            .relativeMountPath(relativeMountPath.applyValue({ args0 -> args0 }))
            .sasKey(sasKey?.applyValue({ args0 -> args0 })).build()
}

/**
 * Builder for [AzureBlobFileSystemConfigurationArgs].
 */
@PulumiTagMarker
public class AzureBlobFileSystemConfigurationArgsBuilder internal constructor() {
    private var accountKey: Output<String>? = null

    private var accountName: Output<String>? = null

    private var blobfuseOptions: Output<String>? = null

    private var containerName: Output<String>? = null

    private var identityReference: Output<ComputeNodeIdentityReferenceArgs>? = null

    private var relativeMountPath: Output<String>? = null

    private var sasKey: Output<String>? = null

    /**
     * @param value This property is mutually exclusive with both sasKey and identity; exactly one must be specified.
     */
    @JvmName("wiwhyqhxqypjfyan")
    public suspend fun accountKey(`value`: Output<String>) {
        this.accountKey = value
    }

    /**
     * @param value
     */
    @JvmName("uwwoflwgxmerkmna")
    public suspend fun accountName(`value`: Output<String>) {
        this.accountName = value
    }

    /**
     * @param value These are 'net use' options in Windows and 'mount' options in Linux.
     */
    @JvmName("kgtnwgjeixhdamlj")
    public suspend fun blobfuseOptions(`value`: Output<String>) {
        this.blobfuseOptions = value
    }

    /**
     * @param value
     */
    @JvmName("coapmjjxwcgqfmcs")
    public suspend fun containerName(`value`: Output<String>) {
        this.containerName = value
    }

    /**
     * @param value This property is mutually exclusive with both accountKey and sasKey; exactly one must be specified.
     */
    @JvmName("rfidigncuodqlflv")
    public suspend fun identityReference(`value`: Output<ComputeNodeIdentityReferenceArgs>) {
        this.identityReference = value
    }

    /**
     * @param value All file systems are mounted relative to the Batch mounts directory, accessible via the AZ_BATCH_NODE_MOUNTS_DIR environment variable.
     */
    @JvmName("knlponqumdfluqgg")
    public suspend fun relativeMountPath(`value`: Output<String>) {
        this.relativeMountPath = value
    }

    /**
     * @param value This property is mutually exclusive with both accountKey and identity; exactly one must be specified.
     */
    @JvmName("ejustuqkuiukqdqo")
    public suspend fun sasKey(`value`: Output<String>) {
        this.sasKey = value
    }

    /**
     * @param value This property is mutually exclusive with both sasKey and identity; exactly one must be specified.
     */
    @JvmName("sftqhuvhjtoxeubm")
    public suspend fun accountKey(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.accountKey = mapped
    }

    /**
     * @param value
     */
    @JvmName("wbpjqmjwvsanxldp")
    public suspend fun accountName(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.accountName = mapped
    }

    /**
     * @param value These are 'net use' options in Windows and 'mount' options in Linux.
     */
    @JvmName("jupqgrhaecmrhodr")
    public suspend fun blobfuseOptions(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.blobfuseOptions = mapped
    }

    /**
     * @param value
     */
    @JvmName("udlukusdtknwpkai")
    public suspend fun containerName(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.containerName = mapped
    }

    /**
     * @param value This property is mutually exclusive with both accountKey and sasKey; exactly one must be specified.
     */
    @JvmName("kemyfkwolaiqcmgg")
    public suspend fun identityReference(`value`: ComputeNodeIdentityReferenceArgs?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.identityReference = mapped
    }

    /**
     * @param argument This property is mutually exclusive with both accountKey and sasKey; exactly one must be specified.
     */
    @JvmName("cvrcleydlgnxtwyf")
    public suspend
    fun identityReference(argument: suspend ComputeNodeIdentityReferenceArgsBuilder.() -> Unit) {
        val toBeMapped = ComputeNodeIdentityReferenceArgsBuilder().applySuspend { argument() }.build()
        val mapped = of(toBeMapped)
        this.identityReference = mapped
    }

    /**
     * @param value All file systems are mounted relative to the Batch mounts directory, accessible via the AZ_BATCH_NODE_MOUNTS_DIR environment variable.
     */
    @JvmName("wctvtpojufmwfott")
    public suspend fun relativeMountPath(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.relativeMountPath = mapped
    }

    /**
     * @param value This property is mutually exclusive with both accountKey and identity; exactly one must be specified.
     */
    @JvmName("pfqgyhwbwofnmtwe")
    public suspend fun sasKey(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.sasKey = mapped
    }

    internal fun build(): AzureBlobFileSystemConfigurationArgs = AzureBlobFileSystemConfigurationArgs(
        accountKey = accountKey,
        accountName = accountName ?: throw PulumiNullFieldException("accountName"),
        blobfuseOptions = blobfuseOptions,
        containerName = containerName ?: throw PulumiNullFieldException("containerName"),
        identityReference = identityReference,
        relativeMountPath = relativeMountPath ?: throw PulumiNullFieldException("relativeMountPath"),
        sasKey = sasKey,
    )
}

==> pulumi-azure-native-kotlin-2.37.0.0-sources.jar: com/pulumi/azurenative/batch/kotlin/inputs/AzureBlobFileSystemConfigurationArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.batch.kotlin.inputs

import com.pulumi.azurenative.batch.inputs.AzureBlobFileSystemConfigurationArgs.builder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiNullFieldException
import com.pulumi.kotlin.PulumiTagMarker
import com.pulumi.kotlin.applySuspend
import kotlin.String
import kotlin.Suppress
import kotlin.Unit
import kotlin.jvm.JvmName

/**
 *
 * @property accountKey This property is mutually exclusive with both sasKey and identity; exactly one must be specified.
 * @property accountName
 * @property blobfuseOptions These are 'net use' options in Windows and 'mount' options in Linux.
 * @property containerName
 * @property identityReference This property is mutually exclusive with both accountKey and sasKey; exactly one must be specified.
 * @property relativeMountPath All file systems are mounted relative to the Batch mounts directory, accessible via the AZ_BATCH_NODE_MOUNTS_DIR environment variable.
 * @property sasKey This property is mutually exclusive with both accountKey and identity; exactly one must be specified.
 */
public data class AzureBlobFileSystemConfigurationArgs(
    public val accountKey: Output<String>? = null,
    public val accountName: Output<String>,
    public val blobfuseOptions: Output<String>? = null,
    public val containerName: Output<String>,
    public val identityReference: Output<ComputeNodeIdentityReferenceArgs>? = null,
    public val relativeMountPath: Output<String>,
    public val sasKey: Output<String>? = null,
) : ConvertibleToJava<com.pulumi.azurenative.batch.inputs.AzureBlobFileSystemConfigurationArgs> {
    override fun toJava(): com.pulumi.azurenative.batch.inputs.AzureBlobFileSystemConfigurationArgs =
        com.pulumi.azurenative.batch.inputs.AzureBlobFileSystemConfigurationArgs.builder()
            .accountKey(accountKey?.applyValue({ args0 -> args0 }))
            .accountName(accountName.applyValue({ args0 -> args0 }))
            .blobfuseOptions(blobfuseOptions?.applyValue({ args0 -> args0 }))
            .containerName(containerName.applyValue({ args0 -> args0 }))
            .identityReference(identityReference?.applyValue({ args0 -> args0.let({ args0 -> args0.toJava() }) }))
            .relativeMountPath(relativeMountPath.applyValue({ args0 -> args0 }))
            .sasKey(sasKey?.applyValue({ args0 -> args0 })).build()
}

/**
 * Builder for [AzureBlobFileSystemConfigurationArgs].
 */
@PulumiTagMarker
public class AzureBlobFileSystemConfigurationArgsBuilder internal constructor() {
    private var accountKey: Output<String>? = null

    private var accountName: Output<String>? = null

    private var blobfuseOptions: Output<String>? = null

    private var containerName: Output<String>? = null

    private var identityReference: Output<ComputeNodeIdentityReferenceArgs>? = null

    private var relativeMountPath: Output<String>? = null

    private var sasKey: Output<String>? = null

    /**
     * @param value This property is mutually exclusive with both sasKey and identity; exactly one must be specified.
     */
    @JvmName("jsnbbiqjobqcagyn")
    public suspend fun accountKey(`value`: Output<String>) {
        this.accountKey = value
    }

    /**
     * @param value
     */
    @JvmName("pnrvcxgjmmkiwnoo")
    public suspend fun accountName(`value`: Output<String>) {
        this.accountName = value
    }

    /**
     * @param value These are 'net use' options in Windows and 'mount' options in Linux.
     */
    @JvmName("usamgmfxxarmgloa")
    public suspend fun blobfuseOptions(`value`: Output<String>) {
        this.blobfuseOptions = value
    }

    /**
     * @param value
     */
    @JvmName("jueckhcjccjsyeem")
    public suspend fun containerName(`value`: Output<String>) {
        this.containerName = value
    }

    /**
     * @param value This property is mutually exclusive with both accountKey and sasKey; exactly one must be specified.
     */
    @JvmName("icfymuypjrfjrjrm")
    public suspend fun identityReference(`value`: Output<ComputeNodeIdentityReferenceArgs>) {
        this.identityReference = value
    }

    /**
     * @param value All file systems are mounted relative to the Batch mounts directory, accessible via the AZ_BATCH_NODE_MOUNTS_DIR environment variable.
     */
    @JvmName("lvwbvcbquuvqfsfh")
    public suspend fun relativeMountPath(`value`: Output<String>) {
        this.relativeMountPath = value
    }

    /**
     * @param value This property is mutually exclusive with both accountKey and identity; exactly one must be specified.
     */
    @JvmName("dfiqmanmxbitmkws")
    public suspend fun sasKey(`value`: Output<String>) {
        this.sasKey = value
    }

    /**
     * @param value This property is mutually exclusive with both sasKey and identity; exactly one must be specified.
     */
    @JvmName("vcxggsvokskjbosw")
    public suspend fun accountKey(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.accountKey = mapped
    }

    /**
     * @param value
     */
    @JvmName("xfytwinkfrxetlvk")
    public suspend fun accountName(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.accountName = mapped
    }

    /**
     * @param value These are 'net use' options in Windows and 'mount' options in Linux.
     */
    @JvmName("nwtormidlrhuwsyp")
    public suspend fun blobfuseOptions(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.blobfuseOptions = mapped
    }

    /**
     * @param value
     */
    @JvmName("spoeumqeapotisos")
    public suspend fun containerName(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.containerName = mapped
    }

    /**
     * @param value This property is mutually exclusive with both accountKey and sasKey; exactly one must be specified.
     */
    @JvmName("bngxyxokablipnjc")
    public suspend fun identityReference(`value`: ComputeNodeIdentityReferenceArgs?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.identityReference = mapped
    }

    /**
     * @param argument This property is mutually exclusive with both accountKey and sasKey; exactly one must be specified.
     */
    @JvmName("fcupvcfjqbuhfqxm")
    public suspend
    fun identityReference(argument: suspend ComputeNodeIdentityReferenceArgsBuilder.() -> Unit) {
        val toBeMapped = ComputeNodeIdentityReferenceArgsBuilder().applySuspend { argument() }.build()
        val mapped = of(toBeMapped)
        this.identityReference = mapped
    }

    /**
     * @param value All file systems are mounted relative to the Batch mounts directory, accessible via the AZ_BATCH_NODE_MOUNTS_DIR environment variable.
     */
    @JvmName("xgvpjtanynmrmsfs")
    public suspend fun relativeMountPath(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.relativeMountPath = mapped
    }

    /**
     * @param value This property is mutually exclusive with both accountKey and identity; exactly one must be specified.
     */
    @JvmName("lbslsovlkjvdnarp")
    public suspend fun sasKey(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.sasKey = mapped
    }

    internal fun build(): AzureBlobFileSystemConfigurationArgs = AzureBlobFileSystemConfigurationArgs(
        accountKey = accountKey,
        accountName = accountName ?: throw PulumiNullFieldException("accountName"),
        blobfuseOptions = blobfuseOptions,
        containerName = containerName ?: throw PulumiNullFieldException("containerName"),
        identityReference = identityReference,
        relativeMountPath = relativeMountPath ?: throw PulumiNullFieldException("relativeMountPath"),
        sasKey = sasKey,
    )
}
